California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 017 - ALLOWS AUTO INSURANCE COMPANIES TO BASE THEIR PRICES IN PART ON A DRIVER'S HISTORY OF INSURANCE COVERAGE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1318927 | YES ON 17-CALIFORNIANS FOR FAIR AUTO INSURANCE RATES AND MERCURY GENERAL CORPORATION AND AFFILIATES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1322520 | STOP PROP 17: SPONSORED BY CAMPAIGN FOR CONSUMER RIGHTS - A COALITION OF CONSUMER ADVOCATES, NURSES AND CONSUMER ATTORNEYS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307787 | HERRERA, CALIFORNIANS FOR PROGRESS, NO ON 23, A COALITION OF CONSUMERS AND DENNIS | OPPOSE